import { forwardRef, createContext, useContext, useMemo } from "react";
import styled from "styled-components";
import { useControllableState, useCallbackRef } from "../hooks";
import { Flex } from "./flex";
import { Box } from "./box";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
const Input = styled.input.withConfig({
  displayName: "checkbox__Input",
  componentId: "sc-12ydcl3-0"
})(["position:absolute;top:0;right:0;bottom:0;left:0;width:100%;height:100%;opacity:0;z-index:1;cursor:pointer;"]);
const Control = styled.span.withConfig({
  displayName: "checkbox__Control",
  componentId: "sc-12ydcl3-1"
})(["display:inline-flex;flex:none;position:relative;top:0;left:0;width:14px;height:14px;background:", ";border:", ";border-radius:", "px;transition:all 0.2s;&::after{position:absolute;top:50%;left:2px;display:table;width:5px;height:9px;border:2px solid #fff;border-top:0;border-left:0;transform:rotate(45deg) scale(0) translate(-50%,-50%);opacity:0;transition:all 0.2s ", ",opacity 0.1s;content:\" \";}"], p => p.theme.colors.gray[1], p => p.theme.borders.base, p => p.theme.radii.base, p => p.theme.transitions.easeOutBack);
const Label = styled.label.withConfig({
  displayName: "checkbox__Label",
  componentId: "sc-12ydcl3-2"
})(["display:inline-flex;align-items:center;vertical-align:top;position:relative;user-select:none;cursor:pointer;&:hover ", "{border-color:", ";}", ":focus + ", "{box-shadow:0 0 0 2px ", ";}&[data-orientation=\"horizontal\"]{flex-direction:row;}&[data-orientation=\"vertical\"]{flex-direction:column;}&[data-state=\"checked\"]{", "{background:", ";border-color:", ";&::after{transform:rotate(45deg) scale(1) translate(-50%,-50%);opacity:1;}}&:hover ", "{background:", ";border-color:", ";}}&[data-invalid]{", "{border-color:", ";}&:hover ", "{border-color:", ";}", ":focus:enabled + ", "{box-shadow:0 0 0 2px ", ";}&[data-state=\"checked\"]{", "{background:", ";border-color:", ";}&:hover ", "{background:", ";border-color:", ";}}}&[data-disabled]{color:", ";&,", "{cursor:not-allowed;}", "{opacity:0.5;background:", " !important;border-color:", " !important;&::after{border-color:", ";}}&[data-state=\"checked\"] ", "{opacity:1;background:", " !important;}}"], Control, p => p.theme.colors.gray[5], Input, Control, p => p.theme.colors.primary[2], Control, p => p.theme.colors.primary.base, p => p.theme.colors.primary.base, Control, p => p.theme.colors.primary.hover, p => p.theme.colors.primary.hover, Control, p => p.theme.colors.danger.base, Control, p => p.theme.colors.danger.hover, Input, Control, p => p.theme.colors.danger[2], Control, p => p.theme.colors.danger.base, p => p.theme.colors.danger.base, Control, p => p.theme.colors.danger.hover, p => p.theme.colors.danger.hover, p => p.theme.colors.disabled, Input, Control, p => p.theme.colors.gray[1], p => p.theme.colors.border.base, p => p.theme.colors.disabled, Control, p => p.theme.colors.gray[4]);
const CheckboxGroupContext = /*#__PURE__*/createContext(undefined);
const CheckboxGroup = /*#__PURE__*/forwardRef((props, ref) => {
  const {
    value: valueProp,
    defaultValue = [],
    onChange,
    name,
    disabled,
    isInvalid,
    color,
    children,
    ...rest
  } = props;
  const [listValue, setListValue] = useControllableState(valueProp, defaultValue);
  const handleChange = useCallbackRef((checked, value) => {
    const val = checked ? [...listValue, value] : listValue.filter(v => v !== value);
    setListValue(val);
    onChange?.(val);
  });
  const group = useMemo(() => ({
    value: listValue,
    onChange: handleChange,
    name,
    disabled,
    isInvalid
  }), [listValue, handleChange, name, disabled, isInvalid]);
  return /*#__PURE__*/_jsx(CheckboxGroupContext.Provider, {
    value: group,
    children: /*#__PURE__*/_jsx(Flex, {
      ref: ref,
      position: "relative",
      width: 1,
      rowGap: 2,
      columnGap: 3,
      wrap: "wrap",
      color: color,
      ...rest,
      children: children
    })
  });
});
const Checkbox = /*#__PURE__*/forwardRef((props, ref) => {
  const {
    checked: checkedProp,
    defaultChecked = false,
    onChange,
    orientation = "horizontal",
    name,
    value = "",
    disabled,
    className,
    children,
    ...rest
  } = props;
  const group = useContext(CheckboxGroupContext);
  const inputName = group?.name ?? name;
  const isDisabled = group?.disabled || disabled;
  const isInvalid = group?.isInvalid;
  const [checked, setChecked] = useControllableState(group?.value.includes(value) ?? checkedProp, defaultChecked);
  const handleChange = event => {
    const checked = event.target.checked;
    setChecked(checked);
    group?.onChange?.(checked, value);
    onChange?.(checked, event);
  };
  return /*#__PURE__*/_jsxs(Label, {
    className: className,
    "data-state": checked ? "checked" : "unchecked",
    "data-orientation": orientation,
    "data-disabled": isDisabled ? "" : null,
    "data-invalid": isInvalid ? "" : null,
    children: [/*#__PURE__*/_jsx(Input, {
      ref: ref,
      type: "checkbox",
      name: inputName,
      value: value,
      checked: checked,
      disabled: isDisabled,
      onChange: handleChange,
      ...rest
    }), /*#__PURE__*/_jsx(Control, {}), children ? /*#__PURE__*/_jsx(Box, {
      pl: orientation === "horizontal" ? 2 : 0,
      pt: orientation === "vertical" ? 2 : 0,
      children: children
    }) : null]
  });
});
const CompoundCheckbox = Object.assign(Checkbox, {
  id: "Checkbox",
  Group: CheckboxGroup
});
export { CompoundCheckbox as Checkbox };
if (process.env.NODE_ENV !== "production") {
  Checkbox.displayName = "Checkbox";
  CheckboxGroup.displayName = "CheckboxGroup";
}