import { memo, forwardRef, useMemo } from "react";
import { system, margin, layout } from "styled-system";
import styled, { css } from "styled-components";
import { hexToRgba, isDarkColor } from "../utils/color-util";
import { jsx as _jsx } from "react/jsx-runtime";
const other = system({
  pointerEvents: true,
  cursor: true
});
const Swatch = styled.span.withConfig({
  displayName: "color-swatch__Swatch",
  componentId: "sc-o4oh22-0"
})(["--accent-color:", ";display:inline-block;position:relative;border-radius:2px;border-color:transparent;box-shadow:", " 0 0 0 1px inset;", " ", " ", " ", " ", ""], p => p.accentColor, p => p.theme.colors.alpha[3], margin, layout, other, p => p.primary && css(["&::before{border-width:", "px;border-style:solid;border-color:var(--accent-color) transparent transparent var(--accent-color);border-radius:2px 0 0 0;transform:translate(1px,1px);position:absolute;top:0;left:0;z-index:1;content:\"\";}"], Math.round((p.size ?? 0) / 4)), p => p.secondary && css(["&::after{border-width:", "px;border-style:solid;border-color:transparent var(--accent-color) var(--accent-color) transparent;border-radius:0 0 2px 0;transform:translate(-1px,-1px);position:absolute;bottom:0;right:0;z-index:1;content:\"\";}"], Math.round((p.size ?? 0) / 6)));
const BaseColorSwatch = /*#__PURE__*/forwardRef((_ref, ref) => {
  let {
    color = "#000000",
    primary,
    secondary,
    size = 20,
    style,
    ...rest
  } = _ref;
  const accentColor = useMemo(() => {
    const rgb = hexToRgba(color);
    return isDarkColor(rgb) ? "#fff" : "#000";
  }, [color]);
  return /*#__PURE__*/_jsx(Swatch, {
    ref: ref,
    ...rest,
    primary: primary,
    secondary: secondary,
    size: size,
    accentColor: accentColor,
    style: {
      backgroundColor: color,
      ...style
    }
  });
});
export const ColorSwatch = /*#__PURE__*/memo(BaseColorSwatch);
if (process.env.NODE_ENV !== "production") {
  ColorSwatch.displayName = "ColorSwatch";
}