import { forwardRef, cloneElement } from "react";
import styled from "styled-components";
import { system, space, layout, position, flexbox, color } from "styled-system";
import { getValidChildren } from "../utils/react-util";
import { useControllableState } from "../hooks";
import { Flex } from "./flex";
import { jsx as _jsx } from "react/jsx-runtime";
const other = system({
  textTransform: true,
  pointerEvents: true,
  cursor: true
});
const StyledInput = styled.input.withConfig({
  displayName: "input__StyledInput",
  componentId: "sc-138b3kp-0"
})(["width:100%;min-width:0;height:24px;padding:0 4px;line-height:", ";outline:0;position:relative;appearance:none;transition:all 0.2s,height 0ms;border:", ";border-radius:", "px;background:", ";", " ", " ", " ", " ", " &:hover:enabled{border-color:", ";}&:focus:enabled{border-color:", ";box-shadow:0 0 0 1px ", ";z-index:1;}&:read-only{user-select:all;}&:disabled{opacity:0.5;cursor:not-allowed;}&[data-invalid]:not(:disabled){border-color:", ";&:hover:enabled{border-color:", ";}&:focus:enabled{border-color:", ";box-shadow:0 0 0 1px ", ";}}"], p => p.theme.lineHeights.base, p => p.theme.borders.base, p => p.theme.radii.base, p => p.theme.colors.gray[1], space, layout, flexbox, color, other, p => p.theme.colors.gray[5], p => p.theme.colors.primary.hover, p => p.theme.colors.primary.hover, p => p.theme.colors.danger.base, p => p.theme.colors.danger.hover, p => p.theme.colors.danger.hover, p => p.theme.colors.danger.hover);
const InputElement = styled.div.withConfig({
  displayName: "input__InputElement",
  componentId: "sc-138b3kp-1"
})(["display:flex;align-items:center;justify-content:center;position:absolute;top:0;width:24px;height:24px;font-size:14px;padding:0 4px;color:", ";pointer-events:none;z-index:2;", " ", " ", " ", " ", " ", ""], p => p.theme.colors.alpha[5], space, layout, position, flexbox, color, other);
const Group = /*#__PURE__*/forwardRef((_ref, ref) => {
  let {
    color,
    children,
    ...rest
  } = _ref;
  const groupStyles = {};
  const validChildren = getValidChildren(children);
  validChildren.forEach(child => {
    if (child.type.id === "InputPrefix") {
      groupStyles.paddingLeft = 24;
    }
    if (child.type.id === "InputSuffix") {
      groupStyles.paddingRight = 24;
    }
  });
  const clones = validChildren.map(child => {
    const {
      pl,
      pr
    } = child.props;
    return child.type.id === "Input" ? /*#__PURE__*/cloneElement(child, {
      pl: pl ?? groupStyles?.paddingLeft,
      pr: pr ?? groupStyles?.paddingRight
    }) : child;
  });
  return /*#__PURE__*/_jsx(Flex, {
    ref: ref,
    position: "relative",
    width: 1,
    zIndex: 0,
    color: color,
    ...rest,
    children: clones
  });
});
const Prefix = /*#__PURE__*/forwardRef((_ref2, ref) => {
  let {
    color,
    ...rest
  } = _ref2;
  return /*#__PURE__*/_jsx(InputElement, {
    ref: ref,
    left: "0",
    color: color,
    ...rest
  });
});
const CompoundPrefix = Object.assign(Prefix, {
  id: "InputPrefix"
});
const Suffix = /*#__PURE__*/forwardRef((_ref3, ref) => {
  let {
    color,
    ...rest
  } = _ref3;
  return /*#__PURE__*/_jsx(InputElement, {
    ref: ref,
    right: "0",
    color: color,
    ...rest
  });
});
const CompoundSuffix = Object.assign(Suffix, {
  id: "InputSuffix"
});
const Input = /*#__PURE__*/forwardRef((props, ref) => {
  const {
    type = "text",
    value,
    defaultValue = "",
    color,
    size,
    width,
    height,
    onChange,
    isInvalid,
    ...rest
  } = props;
  const [inputValue, setInputValue] = useControllableState(value, defaultValue);
  const handleChange = event => {
    const val = event.target.value;
    setInputValue(val);
    onChange?.(val, event);
  };
  return /*#__PURE__*/_jsx(StyledInput, {
    ref: ref,
    type: type,
    value: inputValue,
    onChange: handleChange,
    size: size,
    width: width,
    height: height,
    color: color,
    "data-invalid": isInvalid ? "" : null,
    ...rest
  });
});
const CompoundInput = Object.assign(Input, {
  id: "Input",
  Group: Group,
  Prefix: CompoundPrefix,
  Suffix: CompoundSuffix
});
export { CompoundInput as Input };
if (process.env.NODE_ENV !== "production") {
  Input.displayName = "Input";
  Group.displayName = "InputGroup";
  CompoundPrefix.displayName = "InputPrefix";
  CompoundSuffix.displayName = "InputSuffix";
}